@@ -361,7 +361,7 @@ def histogram(*variables, data, log=True, fig_ax=None):
     return figure, axes
 
 
-def scatter_plot_2d(x, y, *, data, color=None, fig_ax=None):
+def scatter_plot_2d(x, y, *, data, color=None, order=0, fig_ax=None):
     """Plot regression plot between two variables.
 
     Parameters
@@ -373,6 +373,9 @@ def scatter_plot_2d(x, y, *, data, color=None, fig_ax=None):
     color : str or ndarray, optional
         Column name for `data`. Used as the basis for coloring the scatter points using
         a colormap.
+    order : int, optional
+        Fit a regression model to the data if > 0. 1 will use a linear regression,
+        values >= 2 will use a polynomial fit of the specified order.
     fig_ax : (matplotlib.Figure, maptlotlib.Axes), optional
         The figure and axes used to create the plot. If not provided new ones
         will be created.
@@ -398,16 +401,17 @@ def scatter_plot_2d(x, y, *, data, color=None, fig_ax=None):
     # Postpone setting alpha to avoid pale colors in colorbar
     points.set_alpha(0.2)
 
-    sns.regplot(
-        x=x,
-        y=y,
-        data=data,
-        scatter=False,
-        truncate=True,
-        order=6,
-        ax=axes,
-        color=reg_line_color,
-    )
+    if order > 0:
+        sns.regplot(
+            x=x,
+            y=y,
+            data=data,
+            scatter=False,
+            truncate=True,
+            order=order,
+            ax=axes,
+            color=reg_line_color,
+        )
 
     return figure, axes
 
